pub struct FileNameProps { /* private fields */ }Expand description
Metadata history files’ filename contains. The filename can be precisely restored from it.
Implementations
Sourceimpl FileNameProps
impl FileNameProps
Sourcepub fn new(
control: u32,
prev_ctl: u32,
order: Vec<u32>,
tag: Option<String>,
) -> Result<FileNameProps, FsError>
pub fn new( control: u32, prev_ctl: u32, order: Vec<u32>, tag: Option<String>, ) -> Result<FileNameProps, FsError>
Create item from metadata.
pub fn from(filename: &str) -> Option<FileNameProps>
Sourcepub fn prev_ctl(&self) -> u32
pub fn prev_ctl(&self) -> u32
If this item is derived, “control” of the parent item, otherwise this item’s “control”
Sourcepub fn order(&self) -> &[u32]
pub fn order(&self) -> &[u32]
numbers which describes how this item is derived.
if the order is [3,8,2], this item depends on items which has the order of [3] and [3,8]
order.len >= 1
Sourcepub fn order_base(&self) -> &[u32]
pub fn order_base(&self) -> &[u32]
the last item of the order is excluded panics if the order.len() == 0
Sourcepub fn calc_filename(&self) -> String
pub fn calc_filename(&self) -> String
calculate the filename from the metadata this item contains.